/* astroLocations.h
 * Cenon file locations
 *
 * Copyright (C) 2003-2007 by vhf interservice GmbH
 * Author:   Georg Fleischmann
 *
 * created:  2003-03-29
 * modified: 2007-07-22
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the vhf Public License as
 * published by vhf interservice GmbH. Among other things, the
 * License requires that the copyright notices and this notice
 * be preserved on all copies.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the vhf Public License for more details.
 *
 * You should have received a copy of the vhf Public License along
 * with this program; see the file LICENSE. If not, write to vhf.
 *
 * vhf interservice GmbH, Im Marxle 3, 72119 Ammerbuch, Germany
 * eMail: info@vhf.de
 * http://www.vhf.de
 */

#ifndef VHF_H_ASTROLOCATIONS
#define VHF_H_ASTROLOCATIONS

#define APPNAME     @"Cenon"            // the name of the application
#define MODULENAME  @"Astro"            // the name of the module and name of library folder
#define DOCU_ASTRO  @"CenonAstro.pdf"   // the name of the documentation file

/* Astro Chart */
#define CHART_FILE      @"Chart"        // default chart file

/* Map */
#define MAP_FILE        @"Map"          // default map file
#define	MAP_INFOFILE	@"map.plist"	// predefined regions
#define MAP_FOLDER      @"ciamaps"      // map folder

#endif // VHF_H_ASTROLOCATIONS
